@@ -45,6 +45,6 @@ void getShapeExtents(const shape_msgs::SolidPrimitive& shape_msg, double& x_exte
 
 /** \brief Get the dimensions of an axis-aligned bounding box for the shape described by \e shape_msg */
 void getShapeExtents(const shape_msgs::Mesh& shape_msg, double& x_extent, double& y_extent, double& z_extent);
-}
+}  // namespace geometric_shapes
 
 #endif
